@@ -34,8 +34,11 @@ class GetEndpoints:
             final_filter = f"({temp_filter[:-4]}) and {filter}"
 
             # Now call the simple get_data endpoint
-            df_tmp = self.base_class.get_data(uri=uri, xml_root=xml_root, filter=final_filter)
-            df = pd.concat([df, df_tmp], axis=0)
+            try:
+                df_tmp = self.base_class.get_data(uri=uri, xml_root=xml_root, filter=final_filter)
+                df = pd.concat([df, df_tmp], axis=0)
+            except Exception as e:
+                print(f"Error in batch {i}: {e}")
             counter += 10
             print(f'Processed {counter} records from {len(id_list)}')
         return df
